from onvif_utilities.decorator import Registry

PARSERS = Registry()

@PARSERS.register("tns1:RuleEngine/CellMotionDetector/Motion")
async def parse_motion_detector(msg):
    try:
        return {
            "motion" : msg.Message._value_1.Data.SimpleItem[0].Value,
        }
    except (AttributeError, KeyError):
        return None

@PARSERS.register("tns1:RuleEngine/TamperDetector/Tamper")
async def parse_tamper_detector(msg):
    try:
        return {
            "tamper" : msg.Message._value_1.Data.SimpleItem[0].Value == "true",
        }
    except (AttributeError, KeyError):
        return None



ERR_ONVIF_UNKNOWN = 1

class ONVIFError(Exception):
    """ONVIF Exception class."""

    def __init__(self, err):
        self.reason = "Unknown error: " + str(err)
        self.code = ERR_ONVIF_UNKNOWN
        super().__init__(err)

    def __str__(self):
        return self.reason

class ONVIFUtilitiesError(ONVIFError):
    pass


"""ONVIF Service Definitions"""

SERVICES = {
    "devicemgmt": {
        "ns": "http://www.onvif.org/ver10/device/wsdl",
        "wsdl": "devicemgmt.wsdl",
        "binding": "DeviceBinding",
    },
    "media": {
        "ns": "http://www.onvif.org/ver10/media/wsdl",
        "wsdl": "media.wsdl",
        "binding": "MediaBinding",
    },
    "ptz": {
        "ns": "http://www.onvif.org/ver20/ptz/wsdl",
        "wsdl": "ptz.wsdl",
        "binding": "PTZBinding",
    },
    "imaging": {
        "ns": "http://www.onvif.org/ver20/imaging/wsdl",
        "wsdl": "imaging.wsdl",
        "binding": "ImagingBinding",
    },
    "deviceio": {
        "ns": "http://www.onvif.org/ver10/deviceIO/wsdl",
        "wsdl": "deviceio.wsdl",
        "binding": "DeviceIOBinding",
    },
    "events": {
        "ns": "http://www.onvif.org/ver10/events/wsdl",
        "wsdl": "events.wsdl",
        "binding": "EventBinding",
    },
    "pullpoint": {
        "ns": "http://www.onvif.org/ver10/events/wsdl",
        "wsdl": "events.wsdl",
        "binding": "PullPointSubscriptionBinding",
    },
    "notification": {
        "ns": "http://www.onvif.org/ver10/events/wsdl",
        "wsdl": "events.wsdl",
        "binding": "NotificationProducerBinding",
    },
    "subscription": {
        "ns": "http://www.onvif.org/ver10/events/wsdl",
        "wsdl": "events.wsdl",
        "binding": "SubscriptionManagerBinding",
    },
    "analytics": {
        "ns": "http://www.onvif.org/ver20/analytics/wsdl",
        "wsdl": "analytics.wsdl",
        "binding": "AnalyticsEngineBinding",
    },
    "recording": {
        "ns": "http://www.onvif.org/ver10/recording/wsdl",
        "wsdl": "recording.wsdl",
        "binding": "RecordingBinding",
    },
    "search": {
        "ns": "http://www.onvif.org/ver10/search/wsdl",
        "wsdl": "search.wsdl",
        "binding": "SearchBinding",
    },
    "replay": {
        "ns": "http://www.onvif.org/ver10/replay/wsdl",
        "wsdl": "replay.wsdl",
        "binding": "ReplayBinding",
    },
    "receiver": {
        "ns": "http://www.onvif.org/ver10/receiver/wsdl",
        "wsdl": "receiver.wsdl",
        "binding": "ReceiverBinding",
    },
}
